tests: remove reliance of other tests on WITH_TESTS

refs #3609

Change-Id: I8fa858d207cd060cfcda7c86af56dac4afb48fe1
diff --git a/.jenkins.d/10-build.sh b/.jenkins.d/10-build.sh
index c4dc88d..255c7dd 100755
--- a/.jenkins.d/10-build.sh
+++ b/.jenkins.d/10-build.sh
@@ -21,8 +21,8 @@
   # Cleanup
   sudo env "PATH=$PATH" ./waf --color=yes distclean
 
-  # Configure/build in optimized mode without tests
-  ./waf --color=yes configure
+  # Configure/build in optimized mode without tests, but with "other tests"
+  ./waf --color=yes configure --with-other-tests
   ./waf --color=yes build -j${WAF_JOBS:-1}
 
   # Cleanup